"""GROM (Thunder) steering method constants and search priors.

Parameters are required from the optimal config, user CLI args,
or fail loudly at runtime. Search priors encode distribution
knowledge for the unified optimizer.
"""
from wisent.core.utils.config_tools.constants.for_experiments.by_method._tecza import *  # noqa: F401,F403

# --- GROM search priors ---
SP_GROM_NUM_DIR_MU = 1.5
SP_GROM_NUM_DIR_SIGMA = 0.5
SP_GROM_GATE_DIM_MU = 4.0
SP_GROM_GATE_DIM_SIGMA = 1.0
SP_GROM_INTENSITY_DIM_MU = 4.0
SP_GROM_INTENSITY_DIM_SIGMA = 1.0
SP_GROM_OPT_STEPS_MU = 6.0
SP_GROM_OPT_STEPS_SIGMA = 1.0
SP_GROM_WARMUP_MU = 3.0
SP_GROM_WARMUP_SIGMA = 1.0
SP_GROM_BEHAV_WEIGHT_MU = -1.0
SP_GROM_BEHAV_WEIGHT_SIGMA = 1.0
SP_GROM_RETAIN_WEIGHT_MU = 0.5
SP_GROM_RETAIN_WEIGHT_SIGMA = 0.3
SP_GROM_SPARSE_WEIGHT_MU = -3.0
SP_GROM_SPARSE_WEIGHT_SIGMA = 1.5
SP_GROM_SMOOTH_WEIGHT_MU = -3.0
SP_GROM_SMOOTH_WEIGHT_SIGMA = 1.5
SP_GROM_INDEP_WEIGHT_MU = -2.0
SP_GROM_INDEP_WEIGHT_SIGMA = 1.5
SP_GROM_MAX_ALPHA_MU = 0.0
SP_GROM_MAX_ALPHA_SIGMA = 1.0
SP_GROM_GATE_TEMP_MU = -1.0
SP_GROM_GATE_TEMP_SIGMA = 1.0
SP_GROM_MAX_GRAD_NORM_MU = 0.0
SP_GROM_MAX_GRAD_NORM_SIGMA = 1.0
SP_GROM_ETA_MIN_FACTOR_LOW = 0.0
SP_GROM_ETA_MIN_FACTOR_HIGH = 0.2
SP_GROM_LINEAR_THRESH_LOW = 0.5
SP_GROM_LINEAR_THRESH_HIGH = 0.95
SP_GROM_ADAPT_CONE_LOW = 0.3
SP_GROM_ADAPT_CONE_HIGH = 0.8
SP_GROM_ADAPT_MANIFOLD_LOW = 0.5
SP_GROM_ADAPT_MANIFOLD_HIGH = 0.95
SP_GROM_ADAPT_LINEAR_DIR_MIN = 1
SP_GROM_ADAPT_LINEAR_DIR_MAX = 3
SP_GROM_ADAPT_COMPLEX_DIR_MIN = 2
SP_GROM_ADAPT_COMPLEX_DIR_MAX = 8
SP_GROM_ADAPT_MAX_DIR_MIN = 3
SP_GROM_ADAPT_MAX_DIR_MAX = 10
SP_GROM_SIG_DIR_DEFAULT_MIN = 1
SP_GROM_SIG_DIR_DEFAULT_MAX = 5
SP_GROM_MIN_ADAPTED_DIR_MIN = 1
SP_GROM_MIN_ADAPTED_DIR_MAX = 3
SP_GROM_CAA_SIM_SKIP_LOW = 0.8
SP_GROM_CAA_SIM_SKIP_HIGH = 0.99
SP_GROM_CONTRASTIVE_MARGIN_MU = 0.5
SP_GROM_CONTRASTIVE_MARGIN_SIGMA = 0.3
SP_GROM_CONTRASTIVE_WEIGHT_MU = -2.0
SP_GROM_CONTRASTIVE_WEIGHT_SIGMA = 1.5
SP_GROM_UTILITY_WEIGHT_MU = -2.0
SP_GROM_UTILITY_WEIGHT_SIGMA = 1.5
SP_GROM_CONC_WEIGHT_MU = -2.0
SP_GROM_CONC_WEIGHT_SIGMA = 1.5
SP_GROM_GATE_WARMUP_MU = -2.0
SP_GROM_GATE_WARMUP_SIGMA = 1.5
SP_GROM_CAA_ALIGN_MU = -2.0
SP_GROM_CAA_ALIGN_SIGMA = 1.5
SP_GROM_DIM_MIN = 8
SP_GROM_DIM_MAX = 128
SP_GROM_DIM_DIVISOR_MIN = 1
SP_GROM_DIM_DIVISOR_MAX = 8
SP_GROM_SHRINK_MIN = 1
SP_GROM_SHRINK_MAX = 4
SP_GROM_WEIGHT_DECAY_MU = -8.0
SP_GROM_WEIGHT_DECAY_SIGMA = 2.0
SP_GROM_MIN_COS_LOW = 0.0
SP_GROM_MIN_COS_HIGH = 0.5
SP_GROM_MAX_COS_LOW = 0.5
SP_GROM_MAX_COS_HIGH = 1.0
SP_GROM_NOISE_SCALE_MU = -3.0
SP_GROM_NOISE_SCALE_SIGMA = 1.0
SP_GROM_GATE_THRESH_LOW = 0.0
SP_GROM_GATE_THRESH_HIGH = 1.0
SP_GROM_LOG_INTERVAL_MIN = 10
SP_GROM_LOG_INTERVAL_MAX = 100
